# `ds78`

Awesome Portal Gun

**Usage**:

```console
$ ds78 [OPTIONS] COMMAND [ARGS]...
```

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.

**Commands**:

* `load`: Load the portal gun
* `say-hello`: Типа говорит привет и приглашает попить кофе
* `shoot`: Shoot the portal gun

## `ds78 load`

Load the portal gun

**Usage**:

```console
$ ds78 load [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.

## `ds78 say-hello`

Типа говорит привет и приглашает попить кофе

**Usage**:

```console
$ ds78 say-hello [OPTIONS] NAME
```

**Arguments**:

* `NAME`: [required]

**Options**:

* `--city TEXT`
* `--help`: Show this message and exit.

## `ds78 shoot`

Shoot the portal gun

**Usage**:

```console
$ ds78 shoot [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.
